<?php 
//checks to see if image is valid.  If image naming changes this will have to change.
if(preg_match("/^[0-9]{4}([-]{1}[0-9]{3})?_thumb\.jpg$/",$_GET['img'])) {
$image = $_GET['img'];
$lg_img = $name . '_lg.php';
} else { $image = '2005-003-2_thumb.jpg'; } //this one image didn't match the pattern so it is the default.
 ?> 
<html><head></head>
<BODY BGCOLOR="#FFFFCC" LINK="#339933" VLINK="#999933" ALINK="#FF9966">

<center>
<img src="<?php echo $image; ?>">
</center>
</body></html>
